pub struct LockedHeapWithRescue<const ORDER: usize> { /* private fields */ }Expand description
A locked version of Heap with rescue before oom
Usage
Create a locked heap:
use buddy_system_allocator::*;
let heap = LockedHeapWithRescue::new(|heap: &mut Heap<33>, layout: &core::alloc::Layout| {});Before oom, the allocator will try to call rescue function and try for one more time.
Implementations